pub struct TimeWindow {
pub count: usize,
pub time_unit: TimeUnit,
}Expand description
Represents a time window for rate limiting constraints.
This type enables flexible expression of time windows in rate limits:
TimeUnit- defaults to 1 unit (e.g.,TimeUnit::Daysmeans 1 day)(usize, TimeUnit)- explicit count (e.g.,(7, TimeUnit::Days)means 7 days)Duration- converted to best matching TimeUnit
Fields
count: usizetime_unit: TimeUnitTrait Implementations
Sourceimpl Clone for TimeWindow
impl Clone for TimeWindow
Sourcefn clone(&self) -> TimeWindow
fn clone(&self) -> TimeWindow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TimeWindow
Sourceimpl Debug for TimeWindow
impl Debug for TimeWindow
impl Eq for TimeWindow
Sourceimpl From<TimeDelta> for TimeWindow
impl From<TimeDelta> for TimeWindow
Sourceimpl From<TimeUnit> for TimeWindow
impl From<TimeUnit> for TimeWindow
Sourceimpl PartialEq for TimeWindow
impl PartialEq for TimeWindow
Sourcefn eq(&self, other: &TimeWindow) -> bool
fn eq(&self, other: &TimeWindow) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TimeWindow